@@ -255,6 +255,7 @@ def create_app(project_name, settings_path=None, **settings_patches):
         ]
         sed_command = '\\\n'.join(commands)
         local('sed -i.bak -e \'$a\\%s\' %s && rm -rf %s.bak' % (sed_command, apache_conf_path(), apache_conf_path()))
+        local('sudo /usr/sbin/httpd_reload')
 
     port_file_path = os.path.join(project_base_path(project_name), '%d.port' % uwsgi_port)
     local('echo "%d" > %s' % (uwsgi_port, port_file_path))
@@ -291,6 +292,7 @@ def delete_app(project_name, settings_path=None, **settings_patches):
         local('rm -rf %s' % project_base)
 
     local('sed -i.bak -e \'/# %s/,+7d\' %s && rm -rf %s.bak' % (project_name, apache_conf_path(), apache_conf_path()))
+    local('sudo /usr/sbin/httpd_reload')
 
 
 @task
@@ -327,7 +329,8 @@ def update_app(project_name, settings_path=None, **settings_patches):
     config = ConfigParser.ConfigParser()
     if os.path.exists(uwsgi_path):
         config.read(uwsgi_path)
-    else:
+    if not config.has_section('uwsgi'):
+        config.add_section('uwsgi')
         config.set('uwsgi', 'master', True)
         config.set('uwsgi', 'enable-threads', True)
         config.set('uwsgi', 'threads', 20)
@@ -339,7 +342,7 @@ def update_app(project_name, settings_path=None, **settings_patches):
     with hide('everything'):
         uid = local('id -u beanstalk', capture=True)
     config.set('uwsgi', 'uid', uid)
-    config.set('uwsgi', 'logto', project_logs_path(project_name))
+    config.set('uwsgi', 'logto', os.path.join(project_logs_path(project_name), 'uwsgi.log'))
     with open(uwsgi_path, 'wb') as f:
         config.write(f)
 
